function [lacf,ACFx,ACFy,lccf,CCFxy] = lag(varargin);

%  [lacf,ACFx,ACFy,lccf,CCFxy] = lag(x,y,twosided)
%  
%  Time-series analysis of x and y in the lag domain. (must be of same
%  length). The output quantities are as follows:
%  
%   lacf   - lags for autocorrelations
%   lacf   - lags for crosscorrelations
%   ACFx   - autocorrelation function of x
%   ACFy   - autocorrelation function of y
%   CCFxy  - crosscorrelation function of x and y
%  
%  The spectra are averaged with an M-point triangularly weighted window.
%  If M=-1 then the window will be defined as 10% of the length of the
%  series.
%  
%  If only x is specified then the program outputs [lacf,ACFx]

% grab inputs
[cax,args,nargs] = axescheck(varargin{:});
x = args{1};
if nargs > 1
    y = args{2};
end
if nargs == 3
  twosided = args{3};
else
  twosided = 0;
end

% check the sample length
n = length(x);
if nargs == 2
    if ( n ~= length(y) )
        ['Data sets x and y of different lengths!']
        lacf = []; lccf = []; ACFx = []; ACFy = []; CCFxy = [];
        return;
    end
end

% generate autocorrelation functions
[ACFx lacf]  = xcor(x,x);
if nargs == 2
    ACFy         = xcor(y,y);

    % generate crosscorrelation functions
    [CCFxy lccf] = xcor(x,y);
end

% make ACF twosided
