function [cor,lags] = nanxcor(varargin)

%
% [cor,lags] = nanxcor(x,y)
%
% Cross correlation calculation. If only x is specified then
% the output is a one-sided auto-correlation. This version
% of xcor.m can handle missing values as NaN.
%
% The two data sets must be the same length. Positive lags
% mean y leads x
%

% grab inputs, nargs = 1 is x only, nargs = 2 is x and y
[cax,args,nargs] = axescheck(varargin{:});
x = args{1};
n = length(x);
if nargs == 1
  sided = 1;
  lags = 0:(n-1);
  y = x;
elseif nargs == 2
  y = args{2};
  sided = 2;
  lags = (1-n):(n-1);
end

% initialize variables
covxy = zeros(length(lags),1); cor = covxy;

% calculate covariances and correlations
if ( sided == 1 )
  for i=lags
    xx = x(i+1:n); yy = y(1:n-i);
    xm = nanmean(x); ym = nanmean(y); N = length(intersect(find(~isnan(xx)),find(~isnan(yy)))) + i; N = length(x);
    covxy(i+1) = nansum((xx-xm).*(yy-ym)) / N;
    cor(i+1) = covxy(i+1) / sqrt( nanvar(x)*nanvar(y));
  end
elseif ( sided == 2 )
  for i=lags
    if i<0
      i = abs(i);
      xx = x(1:n-i); yy = y(i+1:n);
      xm = nanmean(x); ym = nanmean(y); N = length(intersect(find(~isnan(xx)),find(~isnan(yy)))) + i;
      covxy(n-i) = nansum((xx-xm).*(yy-ym)) / N;
      cor(n-i) = covxy(n-i) / sqrt( nanvar(x)*nanvar(y));
    else
      xx = x(i+1:n); yy = y(1:n-i);
      xm = nanmean(x); ym = nanmean(y); N = length(intersect(find(~isnan(xx)),find(~isnan(yy)))) + i;
      covxy(i+n) = nansum((xx-xm).*(yy-ym)) / N;
      cor(i+n) = covxy(i+n) / sqrt( nanvar(x)*nanvar(y));
    end
  end
end
